
/* gcc -Wall -Werror dbversion.c -lsybdb -o dblib-version */

#include <stdio.h>
#include <stdlib.h>

#include <sybfront.h>
#include <sybdb.h>

int
main(int argc, char *argv[])
{
	if (dbinit() == FAIL) {
		fprintf(stderr, "%s:%d: dbinit() failed!\n", argv[0], __LINE__);
		exit(EXIT_FAILURE);
	}

	printf("%s: \'%s\'.\n", argv[0], dbversion());

	dbexit();

	exit(EXIT_SUCCESS);
}
